@@ -3,8 +3,8 @@ from cdev.resources.simple.iam import PermissionArn, Permission
 powertool_vars = {
     "LOG_LEVEL": "INFO",
     "POWERTOOLS_SERVICE_NAME": "example",
-    "POWERTOOLS_METRICS_NAMESPACE": "PowertoolsDemo"
+    "POWERTOOLS_METRICS_NAMESPACE": "PowertoolsDemo",
 }
 
 # https://docs.aws.amazon.com/lambda/latest/dg/services-xray.html#services-xray-permissions
-tracer_permissions = PermissionArn("arn:aws:iam::aws:policy/AWSXRayDaemonWriteAccess")
\ No newline at end of file
+tracer_permissions = PermissionArn("arn:aws:iam::aws:policy/AWSXRayDaemonWriteAccess")
