@@ -1,8 +1,9 @@
-# Generated as part of Quick Start project template 
+# Generated as part of Quick Start project template
 from aws_lambda_powertools.middleware_factory import lambda_handler_decorator
 
 from cdev.resources.simple.xlambda import simple_function_annotation
 
+
 @lambda_handler_decorator
 def middleware_before_after(handler, event, context):
     print(f"BEFORE")
@@ -12,8 +13,9 @@ def middleware_before_after(handler, event, context):
     print(f"AFTER")
     return response
 
+
 @simple_function_annotation("middleware_example")
 @middleware_before_after
 def lambda_handler(event, context):
 
-    print('Hello from inside your Function!')
+    print("Hello from inside your Function!")
